##  Editing versus Viewing Diagrams
In LeanIX, you work with diagrams in two functional states:
  * Viewing: This is the default view when you open a diagram from the Diagrams tab. In this view, you can explore and manage the diagram as published content. You can navigate, inspect data, use version history, restore versions, export, and share diagrams.
  * Editing: Editing happens in the diagram editor, which you open by clicking Edit in the top-right corner of the Diagrams section. In this view, you can design and modify the diagram structure. You can add shapes and connectors, link to fact sheets, and save changes.


**Note**
If the Edit button is not visible, you may not have permission to edit.
Capability | Viewing  | Editing
---|---|---
Zoom and pan | Yes | Yes
Open linked fact sheets | Yes | Yes
Export as image or PDF | Yes | Yes
View inventory updates | Yes | Yes
Share or copy link | Yes | Yes
Create new diagrams | No | Yes
Modify shapes/connectors | No | Yes
Link elements to fact sheets | No | Yes
Use templates and shape libraries | No | Yes
Apply inventory updates | No | Yes
Browse and open diagrams | Yes | No
Rename diagrams and update metadata | Yes | No
See metadata (owner, dates, sharing) | Yes | No
Access version history | Yes | No
Restore previous version | Yes  | No


